Class: Cleaner::Data
- Inherits:
-
Object
- Object
- Cleaner::Data
- Defined in:
- lib/cleanerupper.rb
Overview
The Dictionary class contains all words that are used by the Cleaner. It also contains other integral components, such as the replacement characters for the replace method.
Constant Summary collapse
- @@dictionaries =
{}
- @@file =
nil- @@cleaner_methods =
[:scramble, :replace, :remove]
- @@replacement_chars =
['*', '@', '!', '$', '%', '&']